@@ -27,6 +27,8 @@ def read_diary():
 def write_diary():
     """ Write your thoughts into the diary file """
     password = input('Введите пароль: ')
+    print('File path', file_path)
+    print('CRP File path', crp_file_path)
 
     is_diary_exists = os.path.isfile(crp_file_path.is_file())
 
